Data directory
==============

This directory contains small data files that are included with the specsim
source code distribution.

Config
------

The ``config`` subdirectory contains YAML configuration files.
See the `configuration documentation page
<http://specsim.readthedocs.io/en/stable/config.html>`__ for details.

Test
----

The ``test`` subdirectory contains input tables referred to by
``config/test.yaml``.  These are simplified inputs provided to allow
this package to be tested without any external inputs.
